@@ -12,7 +12,7 @@ import click
 import requests
 
 from assignment_codeval.canvas_utils import connect_to_canvas, get_course, get_assignment
-from assignment_codeval.commons import debug, error, info, warn
+from assignment_codeval.commons import debug, error, info, warn, despace
 
 
 @click.command()
@@ -82,7 +82,7 @@ def evaluate_submissions(codeval_dir, submissions_dir):
         info(f"processing {dirpath}")
 
         assignment_name = match.group(2)
-        repo_dir = os.path.abspath(os.path.join(dirpath, "repo"))
+        submission_dir = os.path.abspath(os.path.join(dirpath, "submission"))
 
         codeval_file = os.path.join(codeval_dir, f"{assignment_name}.codeval")
         if not os.path.exists(codeval_file):
@@ -104,22 +104,29 @@ def evaluate_submissions(codeval_dir, submissions_dir):
                 if line.startswith("CD"):
                     assignment_working_dir = os.path.normpath(
                         os.path.join(assignment_working_dir, line.split()[1].strip()))
-                    if not os.path.isdir(os.path.join(repo_dir, assignment_working_dir)):
+                    if not os.path.isdir(os.path.join(submission_dir, assignment_working_dir)):
                         out = f"{assignment_working_dir} does not exist or is not a directory\n".encode('utf-8')
                         move_to_next_submission = True
                         break
                 if line.startswith("Z"):
                     zipfile = line.split(None, 1)[1]
-                    # unzip into the repo directory
+                    # unzip into the submission directory
                     with ZipFile(os.path.join(codeval_dir, zipfile)) as zf:
-                        zf.extractall(os.path.join(repo_dir, assignment_working_dir))
+                        for f in zf.infolist():
+                            dest_dir = os.path.join(submission_dir, assignment_working_dir)
+                            zf.extract(f, dest_dir)
+                            if not f.is_dir():
+                                perms = f.external_attr >> 16
+                                if perms:
+                                    os.chmod(os.path.join(dest_dir, f.filename), perms)
+
         if not move_to_next_submission:
             command = raw_command.replace("EVALUATE", "cd /submissions; assignment-codeval run-evaluation codeval.txt")
 
             with TemporaryDirectory("cedir", dir="/var/tmp") as link_dir:
-                repo_link = os.path.join(link_dir, "submissions")
-                os.symlink(repo_dir, repo_link)
-                full_assignment_working_dir = os.path.join(repo_link, assignment_working_dir)
+                submission_link = os.path.join(link_dir, "submissions")
+                os.symlink(submission_dir, submission_link)
+                full_assignment_working_dir = os.path.join(submission_link, assignment_working_dir)
                 shutil.copy(codeval_file, os.path.join(full_assignment_working_dir, "codeval.txt"))
 
                 command = command.replace("SUBMISSIONS", full_assignment_working_dir)
@@ -156,8 +163,9 @@ def evaluate_submissions(codeval_dir, submissions_dir):
               show_default=True)
 @click.option("--codeval-prefix", help="prefix for codeval comments", default="codeval: ", show_default=True)
 @click.option("--include-empty", is_flag=True, help="include empty submissions")
+@click.option("--for-name", help="only download submissions for this student name")
 def download_submissions(course_name, assignment_name, target_dir, include_commented, codeval_prefix, include_empty,
-                         uncommented_for):
+                         uncommented_for, for_name):
     """
     Download submissions for a given assignment in a course from Canvas.
 
@@ -167,12 +175,19 @@ def download_submissions(course_name, assignment_name, target_dir, include_comme
 
     course = get_course(canvas, course_name)
     assignment = get_assignment(course, assignment_name)
-    submission_dir = os.path.join(target_dir, course.name, assignment.name)
+    submission_dir = os.path.join(target_dir, despace(course.name), despace(assignment.name))
     os.makedirs(submission_dir, exist_ok=True)
 
     for submission in assignment.get_submissions(include=["submission_comments", "user"]):
         if not submission.attempt and not include_empty:
             continue
+
+        student_id = str(submission.user_id)
+        student_name = submission.user['name']
+
+        if for_name and for_name not in student_name:
+            continue
+
         submission_comments = [c['created_at'] for c in submission.submission_comments if
                                'comment' in c and c['comment'].startswith(codeval_prefix)]
         submission_comments.sort()
@@ -189,8 +204,6 @@ def download_submissions(course_name, assignment_name, target_dir, include_comme
             if delta.total_seconds() < uncommented_for * 60:
                 continue
 
-        student_id = str(submission.user_id)
-        student_name = submission.user['name']
         student_submission_dir = os.path.join(submission_dir, student_id)
         os.makedirs(student_submission_dir, exist_ok=True)
 
@@ -211,20 +224,11 @@ last_comment={last_comment_date}""", file=fd)
                 fd.write(body)
             debug(f"Downloaded content for student {student_id} to {filepath}")
 
-        if hasattr(submission, "attachment"):
-            attachment = submission.attachment
-            fname = attachment['display_name']
-            prefix = os.path.splitext(fname)[0]
-            suffix = os.path.splitext(fname)[1]
-            durl = attachment['url']
-            filepath = os.path.join(student_submission_dir, f"{prefix}{suffix}")
-
-            with requests.get(durl) as response:
-                if response.status_code != 200:
-                    error(f'error {response.status_code} fetching {durl}')
-                with open(filepath, "wb") as fd:
-                    for chunk in response.iter_content():
-                        fd.write(chunk)
+        if hasattr(submission, "attachments"):
+            for attachment in submission.attachments:
+                fname = attachment.filename
+                filepath = os.path.join(student_submission_dir, fname)
+                attachment.download(filepath)
 
             debug(f"Downloaded submission for student {student_id} to {filepath}")
 
